@@ -31,17 +31,16 @@ Date: Feb 2022
 
 	main file with the interactions
 """
-
-
-
+import pandas as pd
 import streamlit as st
 from tempfile import TemporaryDirectory
 from os.path import join, splitext
 from locale import getdefaultlocale
 import matplotlib.pyplot as plt
-from pladif.attrakdiff import loadCSV, plotWordPair, plotAttrakdiff, plotAverageValues
-from pladif.naming import langOption, plt_pair, plt_attr, plt_avrg
+from pladif.attrakdiff import plotWordPair, plotAttrakdiff, plotAverageValues
+from pladif.naming import langOption, plt_pair, plt_attr, plt_avrg, order_long, pairs, summary_title, summary_info
 from importlib.metadata import version
+from pladif.data import DataAttrakdiff, removeStar
 
 
 
@@ -52,12 +51,23 @@ def updateFileList():
 	# TODO: we can do the same with cache (I guess)!
 	# check the file(s) that are not yet in the dict, and load them
 	newfiles = [f for f in st.session_state.csvFile if f.name not in st.session_state.data]
+	cols = list(st.session_state.data.values())[0].columns if st.session_state.data else []
 	if newfiles:
 		for f in newfiles:
 			try:
-				st.session_state.data[splitext(f.name)[0]] = loadCSV(f)
+				# load the data
+				data = DataAttrakdiff(f)
+				st.session_state.data[splitext(f.name)[0]] = data
+				# compare with previous columns
+				if len(cols) > 0 and (set(data.columns) != set(cols)):
+					st.error("""**Error loading the file `%s`.**
+					 
+					 The file should have the same columns as the other files""", f.name)
 			except ValueError as e:
-				msg.error(str(e))
+				st.error("""**Error loading the file `%s`.**
+				
+				""" % f.name + str(e))
+
 	# check the file(s) that are not anymore in the dict, and del them
 	delfilenames = [
 		name for name in st.session_state.data.keys() if name not in
@@ -73,7 +83,7 @@ def figure(fct, imgFormat, **kwargs):
 	and add a `Download image` button"""
 	# call the function to draw the plot
 	fig, ax = plt.subplots()
-	ret = fct(ax, st.session_state.data, **kwargs)
+	ret = fct(ax, {name: data.df for name, data in st.session_state.data.items()}, **kwargs)
 	st.pyplot(fig)
 	# save it to the file
 	imgFilename = join(tmpFolder.name, fct.__name__ + "." + imgFormat)
@@ -84,6 +94,7 @@ def figure(fct, imgFormat, **kwargs):
 	return ret
 
 
+
 # create a temporary folder, to put the image files
 tmpFolder = TemporaryDirectory()
 
@@ -102,7 +113,6 @@ lang = langs[0] if langs else 'en'
 st.set_page_config(layout="wide")
 
 
-
 # sidebar (to upload files)
 with st.sidebar:
 
@@ -110,26 +120,23 @@ with st.sidebar:
 	st.markdown("<h1 style='text-align: center;'>" + "Add here your CSV files" + "</h1>", unsafe_allow_html=True)
 
 	# file uploader
-	files = st.file_uploader("", type=['csv'], accept_multiple_files=True,
-	    help="The file must be a CSV file, with tab delimiter and UTF-16 encoding (as produced by Usabilla).",
+	files = st.file_uploader("", type=['csv', 'xls', 'xlsx', 'xlsm', 'xlsb', 'odf', 'ods', 'odt'], accept_multiple_files=True,
+	    help="The file must be a CSV file, with tab delimiter and UTF-16 encoding (as produced by Usabilla) or an excel file.",
 	    on_change=updateFileList, key='csvFile'
 	)
 
-	# error message array
-	msg = st.empty()
-
 	# spacing
 	for i in range(4):
 		st.write("")
 
-	# CSV options
-	with st.expander("CSV options"):
-		CSVtype = {
-			True: "Usabilla CSV file (UTF16, tab as delimiter)",
-			False: "CSV file (UTF8 and coma as delimiter)"
-		}
-		CSV = st.selectbox("Choose a CSV type", CSVtype.keys(), format_func=lambda x: CSVtype.get(x), index=0,
-			help="Choose the type of CSV file.", disabled=True)
+	# # CSV options
+	# with st.expander("CSV options"):
+	# 	CSVtype = {
+	# 		True: "Usabilla CSV file (UTF16, tab as delimiter)",
+	# 		False: "CSV file (UTF8 and coma as delimiter)"
+	# 	}
+	# 	CSV = st.selectbox("Choose a CSV type", CSVtype.keys(), format_func=lambda x: CSVtype.get(x), index=0,
+	# 		help="Choose the type of CSV file.", disabled=True)
 
 	# plot options
 	with st.expander("Plot options"):
@@ -159,13 +166,24 @@ st.markdown("<h1 style='text-align:center;'>PLADIF: Plot Attrakdiff graphs from
 
 # plot the graphs and data tables
 if st.session_state.data:
-	# mean values QP, QHI, QHS, ATT
+	# create summary table and remove empty lines
+	st.subheader(summary_title[lang])
+	sumup = pd.DataFrame(
+		[a.summary(order_long, lang) for a in st.session_state.data.values()],
+		index=st.session_state.data.keys(),
+		columns=summary_info[lang]+['%s-%s (%s)' % (*pairs[removeStar(p)][lang], removeStar(p)) for p in order_long]
+	).T
+	sumup.replace("", float("NaN"), inplace=True)
+	sumup.dropna(subset=sumup.columns, inplace=True)
+	sumup.astype(str)
+	st.table(sumup)
+	# average values QP, QHI, QHS, ATT
 	st.subheader(plt_avrg[lang])
 	col1, col2 = st.columns((3, 1))
 	with col1:
 		mv = figure(plotAverageValues, imageFormat, alpha=std, lang=lang)
 	with col2:
-		st.dataframe(mv)
+		st.table(mv)
 
 	# pair words plot
 	st.subheader(plt_pair[lang])
@@ -181,7 +199,7 @@ if st.session_state.data:
 	with col1:
 		attrakdiff = figure(plotAttrakdiff, imageFormat, alpha=std, lang=lang)
 	with col2:
-		st.dataframe(attrakdiff)
+		st.table(attrakdiff)
 
 
 
